KnowLedgeData = {
   "SoftwareAIDocs": "vs_tzkPCBqftVhy78ZbVBKAk5VS", 
   "Books_Python": "vs_bWI8QgwrZRfMUs6sxRghNcUy", 
   "GithubReadme": "vs_ua0NbKDlYfcmuzlj7eLWxZwa", 
   "CompanyCodes": "vs_JcVA69jlQD0oyrmNSUIMrlqt", 
   
}

