/* MAIN QSS STYLESHEET------------------------------------------ */
/*

See Qt documentation:

  - https://doc.qt.io/qt-5/stylesheet.html
  - https://doc.qt.io/qt-5/stylesheet-reference.html
  - https://doc.qt.io/qt-5/stylesheet-examples.html

--------------------------------------------------------------------------- */
/* Reset elements ------------------------------------------------------------

Resetting everything helps to unify styles across different operating systems

--------------------------------------------------------------------------- */
* {
  padding: 0px;
  margin: 0px;
  border: 0px;
  border-style: none;
  border-image: none;
  outline: 0;
  background-color: transparent;
  background: transparent; }

/* specific reset for elements inside QToolBar */
QToolBar * {
  margin: 0px;
  padding: 0px; }

/* QWidget ----------------------------------------------------------------

--------------------------------------------------------------------------- */
QWidget {
  background-color: white;
  border: 0px solid #D8D8D8;
  padding: 0px;
  color: black;
  selection-background-color: #33C9FF;
  selection-color: black; }
  QWidget:disabled {
    background-color: white;
    color: #999999;
    selection-background-color: #00bcff;
    selection-color: #999999; }
  QWidget::item:selected {
    background-color: #33C9FF; }
  QWidget::item:hover:!selected {
    background-color: #66D6FF; }

/* QMainWindow ------------------------------------------------------------

This adjusts the splitter in the dock widget, not qsplitter
https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qmainwindow

--------------------------------------------------------------------------- */
QMainWindow::separator {
  background-color: #D8D8D8;
  border: 0px solid white;
  spacing: 0px;
  padding: 2px; }
  QMainWindow::separator:hover {
    background-color: #BFBFBF;
    border: 0px solid #66D6FF; }
  QMainWindow::separator:horizontal {
    width: 5px;
    margin-top: 2px;
    margin-bottom: 2px;
    image: url("theme-icons:black/feather/toolbar_separator_vertical.png"); }
  QMainWindow::separator:vertical {
    height: 5px;
    margin-left: 2px;
    margin-right: 2px;
    image: url("theme-icons:black/feather/toolbar_separator_horizontal.png"); }

/* QToolTip ---------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qtooltip

--------------------------------------------------------------------------- */
QToolTip {
  background-color: #33C9FF;
  color: black;
  /* If you remove the border property, background stops working on Windows */
  border: none;
  /* Remove padding, for fix combo box tooltip */
  padding: 2px;
  border: 1px solid #BFBFBF;
  border-radius: 3px;
  /* Remove opacity, fix #174 - may need to use RGBA */ }

/* QStatusBar -------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qstatusbar

--------------------------------------------------------------------------- */
QStatusBar {
  border: 1px solid #D8D8D8;
  /* Fixes Spyder #9120, #9121 */
  background: #D8D8D8;
  /* Fixes #205, white vertical borders separating items */ }
  QStatusBar::item {
    border: none; }
  QStatusBar QToolTip {
    background-color: #66D6FF;
    border: 1px solid white;
    color: white;
    /* Remove padding, for fix combo box tooltip */
    padding: 0px;
    /* Reducing transparency to read better */
    opacity: 230; }
  QStatusBar QLabel {
    /* Fixes Spyder #9120, #9121 */
    background: transparent; }

/* QCheckBox --------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qcheckbox

--------------------------------------------------------------------------- */
QCheckBox {
  background-color: white;
  color: black;
  spacing: 4px;
  outline: none;
  padding-top: 4px;
  padding-bottom: 4px; }
  QCheckBox:focus {
    border: none; }
  QCheckBox QWidget:disabled {
    background-color: white;
    color: #999999; }
  QCheckBox::indicator {
    margin-left: 2px;
    height: 14px;
    width: 14px; }
    QCheckBox::indicator:unchecked {
      image: url("theme-icons:black/feather/checkbox_unchecked.png"); }
      QCheckBox::indicator:unchecked:hover, QCheckBox::indicator:unchecked:focus, QCheckBox::indicator:unchecked:pressed {
        border: none;
        image: url("theme-icons:black/feather/checkbox_unchecked.png"); }
      QCheckBox::indicator:unchecked:disabled {
        image: url("theme-icons:black/feather/checkbox_unchecked.png"); }
    QCheckBox::indicator:checked {
      image: url("theme-icons:black/feather/checkbox_checked.png"); }
      QCheckBox::indicator:checked:hover, QCheckBox::indicator:checked:focus, QCheckBox::indicator:checked:pressed {
        border: none;
        image: url("theme-icons:black/feather/checkbox_checked.png"); }
      QCheckBox::indicator:checked:disabled {
        image: url("theme-icons:black/feather/checkbox_checked.png"); }
    QCheckBox::indicator:indeterminate {
      image: url("theme-icons:black/feather/checkbox_indeterminate.png"); }
      QCheckBox::indicator:indeterminate:disabled {
        image: url("theme-icons:black/feather/checkbox_indeterminate.png"); }
      QCheckBox::indicator:indeterminate:focus, QCheckBox::indicator:indeterminate:hover, QCheckBox::indicator:indeterminate:pressed {
        image: url("theme-icons:black/feather/checkbox_indeterminate.png"); }

/* QGroupBox --------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qgroupbox

--------------------------------------------------------------------------- */
QGroupBox {
  font-weight: bold;
  border: 1px solid #D8D8D8;
  border-radius: 4px;
  padding: 2px;
  margin-top: 6px;
  margin-bottom: 4px; }
  QGroupBox::title {
    subcontrol-origin: margin;
    subcontrol-position: top left;
    left: 4px;
    padding-left: 2px;
    padding-right: 4px;
    padding-top: -4px; }
  QGroupBox::indicator {
    margin-left: 2px;
    margin-top: 2px;
    padding: 0;
    height: 14px;
    width: 14px; }
    QGroupBox::indicator:unchecked {
      border: none;
      image: url("theme-icons:black/feather/checkbox_unchecked.png"); }
      QGroupBox::indicator:unchecked:hover, QGroupBox::indicator:unchecked:focus, QGroupBox::indicator:unchecked:pressed {
        border: none;
        image: url("theme-icons:black/feather/checkbox_unchecked.png"); }
      QGroupBox::indicator:unchecked:disabled {
        image: url("theme-icons:black/feather/checkbox_unchecked.png"); }
    QGroupBox::indicator:checked {
      border: none;
      image: url("theme-icons:black/feather/checkbox_checked.png"); }
      QGroupBox::indicator:checked:hover, QGroupBox::indicator:checked:focus, QGroupBox::indicator:checked:pressed {
        border: none;
        image: url("theme-icons:black/feather/checkbox_checked.png"); }
      QGroupBox::indicator:checked:disabled {
        image: url("theme-icons:black/feather/checkbox_checked.png"); }

/* QRadioButton -----------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qradiobutton

--------------------------------------------------------------------------- */
QRadioButton {
  background-color: white;
  color: black;
  spacing: 4px;
  padding-top: 4px;
  padding-bottom: 4px;
  border: none;
  outline: none; }
  QRadioButton:focus {
    border: none; }
  QRadioButton:disabled {
    background-color: white;
    color: #999999;
    border: none;
    outline: none; }
  QRadioButton QWidget {
    background-color: white;
    color: black;
    spacing: 0px;
    padding: 0px;
    outline: none;
    border: none; }
  QRadioButton::indicator {
    border: none;
    outline: none;
    margin-left: 2px;
    height: 14px;
    width: 14px; }
    QRadioButton::indicator:unchecked {
      image: url("theme-icons:black/feather/radio_unchecked.png"); }
      QRadioButton::indicator:unchecked:hover, QRadioButton::indicator:unchecked:focus, QRadioButton::indicator:unchecked:pressed {
        border: none;
        outline: none;
        image: url("theme-icons:black/feather/radio_unchecked.png"); }
      QRadioButton::indicator:unchecked:disabled {
        image: url("theme-icons:black/feather/radio_unchecked.png"); }
    QRadioButton::indicator:checked {
      border: none;
      outline: none;
      image: url("theme-icons:black/feather/radio_checked.png"); }
      QRadioButton::indicator:checked:hover, QRadioButton::indicator:checked:focus, QRadioButton::indicator:checked:pressed {
        border: none;
        outline: none;
        image: url("theme-icons:black/feather/radio_checked.png"); }
      QRadioButton::indicator:checked:disabled {
        outline: none;
        image: url("theme-icons:black/feather/radio_checked.png"); }

/* QMenuBar ---------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qmenubar

--------------------------------------------------------------------------- */
QMenuBar {
  background-color: #D8D8D8;
  padding: 2px;
  border: 1px solid white;
  color: black;
  selection-background-color: #66D6FF; }
  QMenuBar:focus {
    border: 1px solid #33C9FF; }
  QMenuBar::item {
    background: transparent;
    padding: 4px; }
    QMenuBar::item:selected {
      padding: 4px;
      background: transparent;
      border: 0px solid #D8D8D8;
      background-color: #66D6FF; }
    QMenuBar::item:pressed {
      padding: 4px;
      border: 0px solid #D8D8D8;
      background-color: #66D6FF;
      color: black;
      margin-bottom: 0px;
      padding-bottom: 0px; }

/* QMenu ------------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qmenu

--------------------------------------------------------------------------- */
QMenu {
  border: 3px solid #D8D8D8;
  color: black;
  margin: 0px;
  background-color: white;
  selection-background-color: #00bcff; }
  QMenu::separator {
    height: 1px;
    background-color: #BFBFBF;
    color: black; }
  QMenu::item {
    background-color: #E5E5E5;
    padding: 4px 24px 4px 28px;
    /* Reserve space for selection border */
    border: 1px transparent #D8D8D8; }
    QMenu::item:selected {
      color: black;
      background-color: #66D6FF; }
    QMenu::item:pressed {
      background-color: #66D6FF; }
  QMenu::icon {
    padding-left: 10px;
    width: 14px;
    height: 14px; }
  QMenu::indicator {
    padding-left: 8px;
    width: 12px;
    height: 12px;
    /* non-exclusive indicator = check box style indicator (see QActionGroup::setExclusive) */
    /* exclusive indicator = radio button style indicator (see QActionGroup::setExclusive) */ }
    QMenu::indicator:non-exclusive:unchecked {
      image: url("theme-icons:black/feather/checkbox_unchecked.png"); }
      QMenu::indicator:non-exclusive:unchecked:hover, QMenu::indicator:non-exclusive:unchecked:focus, QMenu::indicator:non-exclusive:unchecked:pressed {
        border: none;
        image: url("theme-icons:black/feather/checkbox_unchecked.png"); }
      QMenu::indicator:non-exclusive:unchecked:disabled {
        image: url("theme-icons:black/feather/checkbox_unchecked.png"); }
    QMenu::indicator:non-exclusive:checked {
      image: url("theme-icons:black/feather/checkbox_checked.png"); }
      QMenu::indicator:non-exclusive:checked:hover, QMenu::indicator:non-exclusive:checked:focus, QMenu::indicator:non-exclusive:checked:pressed {
        border: none;
        image: url("theme-icons:black/feather/checkbox_checked.png"); }
      QMenu::indicator:non-exclusive:checked:disabled {
        image: url("theme-icons:black/feather/checkbox_checked.png"); }
    QMenu::indicator:non-exclusive:indeterminate {
      image: url("theme-icons:black/feather/checkbox_indeterminate.png"); }
      QMenu::indicator:non-exclusive:indeterminate:disabled {
        image: url("theme-icons:black/feather/checkbox_indeterminate.png"); }
      QMenu::indicator:non-exclusive:indeterminate:focus, QMenu::indicator:non-exclusive:indeterminate:hover, QMenu::indicator:non-exclusive:indeterminate:pressed {
        image: url("theme-icons:black/feather/checkbox_indeterminate.png"); }
    QMenu::indicator:exclusive:unchecked {
      image: url("theme-icons:black/feather/radio_unchecked.png"); }
      QMenu::indicator:exclusive:unchecked:hover, QMenu::indicator:exclusive:unchecked:focus, QMenu::indicator:exclusive:unchecked:pressed {
        border: none;
        outline: none;
        image: url("theme-icons:black/feather/radio_unchecked.png"); }
      QMenu::indicator:exclusive:unchecked:disabled {
        image: url("theme-icons:black/feather/radio_unchecked.png"); }
    QMenu::indicator:exclusive:checked {
      border: none;
      outline: none;
      image: url("theme-icons:black/feather/radio_checked.png"); }
      QMenu::indicator:exclusive:checked:hover, QMenu::indicator:exclusive:checked:focus, QMenu::indicator:exclusive:checked:pressed {
        border: none;
        outline: none;
        image: url("theme-icons:black/feather/radio_checked.png"); }
      QMenu::indicator:exclusive:checked:disabled {
        outline: none;
        image: url("theme-icons:black/feather/radio_checked.png"); }
  QMenu::right-arrow {
    margin: 5px;
    padding-left: 12px;
    image: url("theme-icons:black/feather/arrow_right.png");
    height: 12px;
    width: 12px; }

/* QAbstractItemView ------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qcombobox

--------------------------------------------------------------------------- */
QAbstractItemView {
  alternate-background-color: white;
  color: black;
  border: 1px solid #D8D8D8;
  border-radius: 4px; }
  QAbstractItemView QLineEdit {
    padding: 2px; }

/* QAbstractScrollArea ----------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qabstractscrollarea

--------------------------------------------------------------------------- */
QAbstractScrollArea {
  background-color: white;
  border: 1px solid #D8D8D8;
  border-radius: 4px;
  /* fix #159 */
  padding: 2px;
  /* remove min-height to fix #244 */
  color: black; }
  QAbstractScrollArea:disabled {
    color: #999999; }

/* QScrollArea ------------------------------------------------------------

--------------------------------------------------------------------------- */
QScrollArea QWidget QWidget:disabled {
  background-color: white; }

/* QScrollBar -------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qscrollbar

--------------------------------------------------------------------------- */
QScrollBar:horizontal {
  height: 16px;
  margin: 2px 16px 2px 16px;
  border: 1px solid #D8D8D8;
  border-radius: 4px;
  background-color: white; }

QScrollBar:vertical {
  background-color: white;
  width: 16px;
  margin: 16px 2px 16px 2px;
  border: 1px solid #D8D8D8;
  border-radius: 4px; }

QScrollBar::handle:horizontal {
  background-color: #BFBFBF;
  border: 1px solid #D8D8D8;
  border-radius: 4px;
  min-width: 8px; }
  QScrollBar::handle:horizontal:hover {
    background-color: #33C9FF;
    border: #33C9FF;
    border-radius: 4px;
    min-width: 8px; }
  QScrollBar::handle:horizontal:focus {
    border: 1px solid #66D6FF; }

QScrollBar::handle:vertical {
  background-color: #BFBFBF;
  border: 1px solid #D8D8D8;
  min-height: 8px;
  border-radius: 4px; }
  QScrollBar::handle:vertical:hover {
    background-color: #33C9FF;
    border: #33C9FF;
    border-radius: 4px;
    min-height: 8px; }
  QScrollBar::handle:vertical:focus {
    border: 1px solid #66D6FF; }

QScrollBar::add-line:horizontal {
  margin: 0px 0px 0px 0px;
  border-image: url("theme-icons:black/feather/arrow_right.png");
  height: 12px;
  width: 12px;
  subcontrol-position: right;
  subcontrol-origin: margin; }
  QScrollBar::add-line:horizontal:hover, QScrollBar::add-line:horizontal:on {
    border-image: url("theme-icons:black/feather/arrow_right.png");
    height: 12px;
    width: 12px;
    subcontrol-position: right;
    subcontrol-origin: margin; }

QScrollBar::add-line:vertical {
  margin: 3px 0px 3px 0px;
  border-image: url("theme-icons:black/feather/arrow_down.png");
  height: 12px;
  width: 12px;
  subcontrol-position: bottom;
  subcontrol-origin: margin; }
  QScrollBar::add-line:vertical:hover, QScrollBar::add-line:vertical:on {
    border-image: url("theme-icons:black/feather/arrow_down.png");
    height: 12px;
    width: 12px;
    subcontrol-position: bottom;
    subcontrol-origin: margin; }

QScrollBar::sub-line:horizontal {
  margin: 0px 3px 0px 3px;
  border-image: url("theme-icons:black/feather/arrow_left.png");
  height: 12px;
  width: 12px;
  subcontrol-position: left;
  subcontrol-origin: margin; }
  QScrollBar::sub-line:horizontal:hover, QScrollBar::sub-line:horizontal:on {
    border-image: url("theme-icons:black/feather/arrow_left.png");
    height: 12px;
    width: 12px;
    subcontrol-position: left;
    subcontrol-origin: margin; }

QScrollBar::sub-line:vertical {
  margin: 3px 0px 3px 0px;
  border-image: url("theme-icons:black/feather/arrow_up.png");
  height: 12px;
  width: 12px;
  subcontrol-position: top;
  subcontrol-origin: margin; }
  QScrollBar::sub-line:vertical:hover, QScrollBar::sub-line:vertical:on {
    border-image: url("theme-icons:black/feather/arrow_up.png");
    height: 12px;
    width: 12px;
    subcontrol-position: top;
    subcontrol-origin: margin; }

QScrollBar::up-arrow:horizontal, QScrollBar::down-arrow:horizontal {
  background: none; }

QScrollBar::up-arrow:vertical, QScrollBar::down-arrow:vertical {
  background: none; }

QScrollBar::add-page:horizontal, QScrollBar::sub-page:horizontal {
  background: none; }

QScrollBar::add-page:vertical, QScrollBar::sub-page:vertical {
  background: none; }

/* QTextEdit --------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-specific-widgets

--------------------------------------------------------------------------- */
QTextEdit {
  background-color: white;
  color: black;
  border-radius: 4px;
  border: 1px solid #D8D8D8; }
  QTextEdit:focus {
    border: 1px solid #66D6FF; }
  QTextEdit:selected {
    background: #33C9FF;
    color: #D8D8D8; }

/* QPlainTextEdit ---------------------------------------------------------

--------------------------------------------------------------------------- */
QPlainTextEdit {
  background-color: white;
  color: black;
  border-radius: 4px;
  border: 1px solid #D8D8D8; }
  QPlainTextEdit:focus {
    border: 1px solid #66D6FF; }
  QPlainTextEdit:selected {
    background: #33C9FF;
    color: #D8D8D8; }

/* QSizeGrip --------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qsizegrip

--------------------------------------------------------------------------- */
QSizeGrip {
  background: transparent;
  width: 12px;
  height: 12px;
  image: url("theme-icons:black/feather/window_grip.png"); }

/* QStackedWidget ---------------------------------------------------------

--------------------------------------------------------------------------- */
QStackedWidget {
  padding: 2px;
  border: 1px solid #D8D8D8;
  border: 1px solid white; }

/* QToolBar ---------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qtoolbar

--------------------------------------------------------------------------- */
QToolBar {
  background-color: #D8D8D8;
  border-bottom: 1px solid white;
  padding: 1px;
  font-weight: bold;
  spacing: 2px; }
  QToolBar:disabled {
    /* Fixes #272 */
    background-color: #D8D8D8; }
  QToolBar::handle:horizontal {
    width: 16px;
    image: url("theme-icons:black/feather/toolbar_move_horizontal.png"); }
  QToolBar::handle:vertical {
    height: 16px;
    image: url("theme-icons:black/feather/toolbar_move_vertical.png"); }
  QToolBar::separator:horizontal {
    width: 16px;
    image: url("theme-icons:black/feather/toolbar_separator_horizontal.png"); }
  QToolBar::separator:vertical {
    height: 16px;
    image: url("theme-icons:black/feather/toolbar_separator_vertical.png"); }

QToolButton#qt_toolbar_ext_button {
  background: #D8D8D8;
  border: 0px;
  color: black;
  image: url("theme-icons:black/feather/arrow_right.png"); }

/* QAbstractSpinBox -------------------------------------------------------

--------------------------------------------------------------------------- */
QAbstractSpinBox {
  background-color: white;
  border: 1px solid #D8D8D8;
  color: black;
  /* This fixes 103, 111 */
  padding-top: 2px;
  /* This fixes 103, 111 */
  padding-bottom: 2px;
  padding-left: 4px;
  padding-right: 4px;
  border-radius: 4px;
  /* min-width: 5px; removed to fix 109 */ }
  QAbstractSpinBox:up-button {
    background-color: transparent white;
    subcontrol-origin: border;
    subcontrol-position: top right;
    border-left: 1px solid #D8D8D8;
    border-bottom: 1px solid #D8D8D8;
    border-top-left-radius: 0;
    border-bottom-left-radius: 0;
    margin: 1px;
    width: 12px;
    margin-bottom: -1px; }
  QAbstractSpinBox::up-arrow, QAbstractSpinBox::up-arrow:disabled, QAbstractSpinBox::up-arrow:off {
    image: url("theme-icons:black/feather/arrow_up.png");
    height: 8px;
    width: 8px; }
  QAbstractSpinBox::up-arrow:hover {
    image: url("theme-icons:black/feather/arrow_up.png"); }
  QAbstractSpinBox:down-button {
    background-color: transparent white;
    subcontrol-origin: border;
    subcontrol-position: bottom right;
    border-left: 1px solid #D8D8D8;
    border-top: 1px solid #D8D8D8;
    border-top-left-radius: 0;
    border-bottom-left-radius: 0;
    margin: 1px;
    width: 12px;
    margin-top: -1px; }
  QAbstractSpinBox::down-arrow, QAbstractSpinBox::down-arrow:disabled, QAbstractSpinBox::down-arrow:off {
    image: url("theme-icons:black/feather/arrow_down.png");
    height: 8px;
    width: 8px; }
  QAbstractSpinBox::down-arrow:hover {
    image: url("theme-icons:black/feather/arrow_down.png"); }
  QAbstractSpinBox:hover {
    border: 1px solid #33C9FF;
    color: black; }
  QAbstractSpinBox:focus {
    border: 1px solid #66D6FF; }
  QAbstractSpinBox:selected {
    background: #33C9FF;
    color: #D8D8D8; }

/* ------------------------------------------------------------------------ */
/* DISPLAYS --------------------------------------------------------------- */
/* ------------------------------------------------------------------------ */
/* QLabel -----------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qframe

--------------------------------------------------------------------------- */
QLabel {
  padding: 2px;
  margin: 0px;
  color: black; }
  QLabel:disabled {
    background-color: white;
    border: 0px solid #D8D8D8;
    color: #999999; }

/* QTextBrowser -----------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qabstractscrollarea

--------------------------------------------------------------------------- */
QTextBrowser {
  background-color: white;
  border: 1px solid #D8D8D8;
  color: black;
  border-radius: 4px; }
  QTextBrowser:disabled {
    background-color: white;
    border: 1px solid #D8D8D8;
    color: #999999;
    border-radius: 4px; }
  QTextBrowser:hover, QTextBrowser:!hover, QTextBrowser:selected, QTextBrowser:pressed {
    border: 1px solid #D8D8D8; }

/* QGraphicsView ----------------------------------------------------------

--------------------------------------------------------------------------- */
QGraphicsView {
  background-color: white;
  border: 1px solid #D8D8D8;
  color: black;
  border-radius: 4px; }
  QGraphicsView:disabled {
    background-color: white;
    border: 1px solid #D8D8D8;
    color: #999999;
    border-radius: 4px; }
  QGraphicsView:hover, QGraphicsView:!hover, QGraphicsView:selected, QGraphicsView:pressed {
    border: 1px solid #D8D8D8; }

/* QCalendarWidget --------------------------------------------------------

--------------------------------------------------------------------------- */
QCalendarWidget {
  background-color: white;
  border: 1px solid #D8D8D8;
  border-radius: 4px; }
  QCalendarWidget:disabled {
    background-color: white;
    color: #999999; }

/* QLCDNumber -------------------------------------------------------------

--------------------------------------------------------------------------- */
QLCDNumber {
  background-color: white;
  color: black; }
  QLCDNumber:disabled {
    background-color: white;
    color: #999999; }

/* QProgressBar -----------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qprogressbar

--------------------------------------------------------------------------- */
QProgressBar {
  background-color: white;
  border: 1px solid #D8D8D8;
  color: black;
  border-radius: 4px;
  text-align: center; }
  QProgressBar:disabled {
    background-color: white;
    border: 1px solid #D8D8D8;
    color: #999999;
    border-radius: 4px;
    text-align: center; }
  QProgressBar::chunk {
    background-color: #33C9FF;
    color: white;
    border-radius: 4px; }
    QProgressBar::chunk:disabled {
      background-color: #00bcff;
      color: #999999;
      border-radius: 4px; }

/* ------------------------------------------------------------------------ */
/* BUTTONS ---------------------------------------------------------------- */
/* ------------------------------------------------------------------------ */
/* QPushButton ------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qpushbutton

--------------------------------------------------------------------------- */
QPushButton {
  background-color: #E5E5E5;
  color: black;
  border-radius: 4px;
  padding: 2px;
  outline: none;
  border: none; }
  QPushButton:disabled {
    background-color: #D8D8D8;
    color: #999999;
    border-radius: 4px;
    padding: 2px; }
  QPushButton:checked {
    background-color: #BFBFBF;
    border-radius: 4px;
    padding: 2px;
    outline: none; }
    QPushButton:checked:disabled {
      background-color: #BFBFBF;
      color: #999999;
      border-radius: 4px;
      padding: 2px;
      outline: none; }
    QPushButton:checked:selected {
      background: #BFBFBF; }
  QPushButton:hover {
    background-color: #CCCCCC;
    color: black; }
  QPushButton:pressed {
    background-color: #BFBFBF; }
  QPushButton:selected {
    background: #BFBFBF;
    color: black; }
  QPushButton::menu-indicator {
    subcontrol-origin: padding;
    subcontrol-position: bottom right;
    bottom: 4px; }

QDialogButtonBox QPushButton {
  /* Issue #194 #248 - Special case of QPushButton inside dialogs, for better UI */
  min-width: 80px; }

/* QToolButton ------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qtoolbutton

--------------------------------------------------------------------------- */
QToolButton {
  background-color: #D8D8D8;
  color: black;
  border-radius: 4px;
  padding: 2px;
  outline: none;
  border: none;
  /* The subcontrols below are used only in the DelayedPopup mode */
  /* The subcontrols below are used only in the MenuButtonPopup mode */
  /* The subcontrol below is used only in the InstantPopup or DelayedPopup mode */ }
  QToolButton:disabled {
    background-color: #D8D8D8;
    color: #999999;
    border-radius: 4px;
    padding: 2px; }
  QToolButton:checked {
    background-color: #BFBFBF;
    border-radius: 4px;
    padding: 2px;
    outline: none; }
    QToolButton:checked:disabled {
      background-color: #BFBFBF;
      color: #999999;
      border-radius: 4px;
      padding: 2px;
      outline: none; }
    QToolButton:checked:hover {
      background-color: #CCCCCC;
      color: black; }
    QToolButton:checked:pressed {
      background-color: #BFBFBF; }
    QToolButton:checked:selected {
      background: #BFBFBF;
      color: black; }
  QToolButton:hover {
    background-color: #CCCCCC;
    color: black; }
  QToolButton:pressed {
    background-color: #BFBFBF; }
  QToolButton:selected {
    background: #BFBFBF;
    color: black; }
  QToolButton[popupMode="0"] {
    /* Only for DelayedPopup */
    padding-right: 2px; }
  QToolButton[popupMode="1"] {
    /* Only for MenuButtonPopup */
    padding-right: 20px; }
    QToolButton[popupMode="1"]::menu-button {
      border: none; }
      QToolButton[popupMode="1"]::menu-button:hover {
        border: none;
        border-left: 1px solid #D8D8D8;
        border-radius: 0; }
  QToolButton[popupMode="2"] {
    /* Only for InstantPopup */
    padding-right: 2px; }
  QToolButton::menu-button {
    padding: 2px;
    border-radius: 4px;
    width: 12px;
    border: none;
    outline: none; }
    QToolButton::menu-button:hover {
      border: 1px solid #33C9FF; }
    QToolButton::menu-button:checked:hover {
      border: 1px solid #33C9FF; }
  QToolButton::menu-indicator {
    image: url("theme-icons:black/feather/arrow_down.png");
    height: 8px;
    width: 8px;
    top: 0;
    /* Exclude a shift for better image */
    left: -2px;
    /* Shift it a bit */ }
  QToolButton::menu-arrow {
    image: url("theme-icons:black/feather/arrow_down.png");
    height: 8px;
    width: 8px; }
    QToolButton::menu-arrow:hover {
      image: url("theme-icons:black/feather/arrow_down.png"); }

/* QCommandLinkButton -----------------------------------------------------

--------------------------------------------------------------------------- */
QCommandLinkButton {
  background-color: transparent;
  border: 1px solid #D8D8D8;
  color: black;
  border-radius: 4px;
  padding: 0px;
  margin: 0px; }
  QCommandLinkButton:disabled {
    background-color: transparent;
    color: #999999; }

/* ------------------------------------------------------------------------ */
/* INPUTS - NO FIELDS ----------------------------------------------------- */
/* ------------------------------------------------------------------------ */
/* QComboBox --------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qcombobox

--------------------------------------------------------------------------- */
QComboBox {
  border: 1px solid #D8D8D8;
  border-radius: 4px;
  selection-background-color: #33C9FF;
  padding-left: 4px;
  padding-right: 4px;
  /* padding-right = 36; 4 + 16*2 See scrollbar size */
  /* changed to 4px to fix #239 */
  /* Fixes #103, #111 */
  min-height: 1.5em;
  /* padding-top: 2px;     removed to fix #132 */
  /* padding-bottom: 2px;  removed to fix #132 */
  /* min-width: 75px;      removed to fix #109 */
  /* Needed to remove indicator - fix #132 */ }
  QComboBox QAbstractItemView {
    border: 1px solid #D8D8D8;
    border-radius: 0;
    background-color: white;
    selection-background-color: #33C9FF; }
    QComboBox QAbstractItemView:hover {
      background-color: white;
      color: black; }
    QComboBox QAbstractItemView:selected {
      background: #33C9FF;
      color: #D8D8D8; }
    QComboBox QAbstractItemView:alternate {
      background: white; }
  QComboBox:disabled {
    background-color: white;
    color: #999999; }
  QComboBox:hover {
    border: 1px solid #33C9FF; }
  QComboBox:focus {
    border: 1px solid #66D6FF; }
  QComboBox:on {
    selection-background-color: #33C9FF; }
  QComboBox::indicator {
    border: none;
    border-radius: 0;
    background-color: transparent;
    selection-background-color: transparent;
    color: transparent;
    selection-color: transparent;
    /* Needed to remove indicator - fix #132 */ }
    QComboBox::indicator:alternate {
      background: white; }
  QComboBox::item {
    height: 20px; }
    QComboBox::item:alternate {
      background: white; }
    QComboBox::item:checked {
      font-weight: bold; }
    QComboBox::item:selected {
      border: 0px solid transparent; }
  QComboBox::drop-down {
    subcontrol-position: top right;
    width: 12px;
    border-left: 1px solid #D8D8D8; }
  QComboBox::down-arrow {
    image: url("theme-icons:black/feather/arrow_down.png");
    height: 8px;
    width: 8px; }
    QComboBox::down-arrow:on, QComboBox::down-arrow:hover, QComboBox::down-arrow:focus {
      image: url("theme-icons:black/feather/arrow_down.png"); }

/* QSlider ----------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qslider

--------------------------------------------------------------------------- */
QSlider:disabled {
  background: white; }

QSlider:focus {
  border: none; }

QSlider::groove:horizontal {
  background: #D8D8D8;
  border: 1px solid #D8D8D8;
  height: 4px;
  margin: 0px;
  border-radius: 4px; }

QSlider::groove:vertical {
  background: #D8D8D8;
  border: 1px solid #D8D8D8;
  width: 4px;
  margin: 0px;
  border-radius: 4px; }

QSlider::add-page:vertical {
  background: #33C9FF;
  border: 1px solid #D8D8D8;
  width: 4px;
  margin: 0px;
  border-radius: 4px; }
  QSlider::add-page:vertical :disabled {
    background: #00bcff; }

QSlider::sub-page:horizontal {
  background: #33C9FF;
  border: 1px solid #D8D8D8;
  height: 4px;
  margin: 0px;
  border-radius: 4px; }
  QSlider::sub-page:horizontal:disabled {
    background: #00bcff; }

QSlider::handle:horizontal {
  background: #999999;
  border: 1px solid #D8D8D8;
  width: 8px;
  height: 8px;
  margin: -8px 0px;
  border-radius: 4px; }
  QSlider::handle:horizontal:hover {
    background: #33C9FF;
    border: 1px solid #33C9FF; }
  QSlider::handle:horizontal:focus {
    border: 1px solid #66D6FF; }

QSlider::handle:vertical {
  background: #999999;
  border: 1px solid #D8D8D8;
  width: 8px;
  height: 8px;
  margin: 0 -8px;
  border-radius: 4px; }
  QSlider::handle:vertical:hover {
    background: #33C9FF;
    border: 1px solid #33C9FF; }
  QSlider::handle:vertical:focus {
    border: 1px solid #66D6FF; }

/* QLineEdit --------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qlineedit

--------------------------------------------------------------------------- */
QLineEdit {
  background-color: white;
  padding-top: 2px;
  /* This QLineEdit fix  103, 111 */
  padding-bottom: 2px;
  /* This QLineEdit fix  103, 111 */
  padding-left: 4px;
  padding-right: 4px;
  border-style: solid;
  border: 1px solid #D8D8D8;
  border-radius: 4px;
  color: black; }
  QLineEdit:disabled {
    background-color: white;
    color: #999999; }
  QLineEdit:hover {
    border: 1px solid #33C9FF;
    color: black; }
  QLineEdit:focus {
    border: 1px solid #66D6FF; }
  QLineEdit:selected {
    background-color: #33C9FF;
    color: #D8D8D8; }

/* QTabWiget --------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qtabwidget-and-qtabbar

--------------------------------------------------------------------------- */
QTabWidget {
  padding: 2px;
  selection-background-color: #D8D8D8; }
  QTabWidget QWidget {
    /* Fixes #189 */
    border-radius: 4px; }
  QTabWidget::pane {
    border: 1px solid #D8D8D8;
    border-radius: 4px;
    margin: 0px;
    /* Fixes double border inside pane with pyqt5 */
    padding: 0px; }
    QTabWidget::pane:selected {
      background-color: #D8D8D8;
      border: 1px solid #33C9FF; }

/* QTabBar ----------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qtabwidget-and-qtabbar

--------------------------------------------------------------------------- */
QTabBar, QDockWidget QTabBar {
  qproperty-drawBase: 0;
  border-radius: 4px;
  margin: 0px;
  padding: 2px;
  border: 0;
  /* left: 5px; move to the right by 5px - removed for fix */ }
  QTabBar::close-button, QDockWidget QTabBar::close-button {
    border: 0;
    margin: 0;
    padding: 4px;
    image: url("theme-icons:black/feather/window_close.png"); }
    QTabBar::close-button:hover, QDockWidget QTabBar::close-button:hover {
      image: url("theme-icons:black/feather/window_close.png"); }
    QTabBar::close-button:pressed, QDockWidget QTabBar::close-button:pressed {
      image: url("theme-icons:black/feather/window_close_pressed.png"); }
  QTabBar::tab, QDockWidget QTabBar::tab {
    /* !selected and disabled ----------------------------------------- */
    /* selected ------------------------------------------------------- */ }
    QTabBar::tab:top:selected:disabled, QDockWidget QTabBar::tab:top:selected:disabled {
      border-bottom: 3px solid #00bcff;
      color: #999999;
      background-color: #D8D8D8; }
    QTabBar::tab:bottom:selected:disabled, QDockWidget QTabBar::tab:bottom:selected:disabled {
      border-top: 3px solid #00bcff;
      color: #999999;
      background-color: #D8D8D8; }
    QTabBar::tab:left:selected:disabled, QDockWidget QTabBar::tab:left:selected:disabled {
      border-right: 3px solid #00bcff;
      color: #999999;
      background-color: #D8D8D8; }
    QTabBar::tab:right:selected:disabled, QDockWidget QTabBar::tab:right:selected:disabled {
      border-left: 3px solid #00bcff;
      color: #999999;
      background-color: #D8D8D8; }
    QTabBar::tab:top:!selected:disabled, QDockWidget QTabBar::tab:top:!selected:disabled {
      border-bottom: 3px solid white;
      color: #999999;
      background-color: white; }
    QTabBar::tab:bottom:!selected:disabled, QDockWidget QTabBar::tab:bottom:!selected:disabled {
      border-top: 3px solid white;
      color: #999999;
      background-color: white; }
    QTabBar::tab:left:!selected:disabled, QDockWidget QTabBar::tab:left:!selected:disabled {
      border-right: 3px solid white;
      color: #999999;
      background-color: white; }
    QTabBar::tab:right:!selected:disabled, QDockWidget QTabBar::tab:right:!selected:disabled {
      border-left: 3px solid white;
      color: #999999;
      background-color: white; }
    QTabBar::tab:top:!selected, QDockWidget QTabBar::tab:top:!selected {
      border-bottom: 2px solid white;
      margin-top: 2px; }
    QTabBar::tab:bottom:!selected, QDockWidget QTabBar::tab:bottom:!selected {
      border-top: 2px solid white;
      margin-bottom: 2px; }
    QTabBar::tab:left:!selected, QDockWidget QTabBar::tab:left:!selected {
      border-left: 2px solid white;
      margin-right: 2px; }
    QTabBar::tab:right:!selected, QDockWidget QTabBar::tab:right:!selected {
      border-right: 2px solid white;
      margin-left: 2px; }
    QTabBar::tab:top, QDockWidget QTabBar::tab:top {
      background-color: #D8D8D8;
      margin-left: 2px;
      padding-left: 4px;
      padding-right: 4px;
      padding-top: 2px;
      padding-bottom: 2px;
      min-width: 5px;
      border-bottom: 3px solid #D8D8D8;
      border-top-left-radius: 4px;
      border-top-right-radius: 4px; }
      QTabBar::tab:top:selected, QDockWidget QTabBar::tab:top:selected {
        background-color: #CCCCCC;
        border-bottom: 3px solid #99E4FF;
        border-top-left-radius: 4px;
        border-top-right-radius: 4px; }
      QTabBar::tab:top:!selected:hover, QDockWidget QTabBar::tab:top:!selected:hover {
        border: 1px solid #66D6FF;
        border-bottom: 3px solid #66D6FF;
        /* Fixes spyder-ide/spyder#9766 and #243 */
        padding-left: 3px;
        padding-right: 3px; }
    QTabBar::tab:bottom, QDockWidget QTabBar::tab:bottom {
      border-top: 3px solid #D8D8D8;
      background-color: #D8D8D8;
      margin-left: 2px;
      padding-left: 4px;
      padding-right: 4px;
      padding-top: 2px;
      padding-bottom: 2px;
      border-bottom-left-radius: 4px;
      border-bottom-right-radius: 4px;
      min-width: 5px; }
      QTabBar::tab:bottom:selected, QDockWidget QTabBar::tab:bottom:selected {
        background-color: #CCCCCC;
        border-top: 3px solid #99E4FF;
        border-bottom-left-radius: 4px;
        border-bottom-right-radius: 4px; }
      QTabBar::tab:bottom:!selected:hover, QDockWidget QTabBar::tab:bottom:!selected:hover {
        border: 1px solid #66D6FF;
        border-top: 3px solid #66D6FF;
        /* Fixes spyder-ide/spyder#9766 and #243 */
        padding-left: 3px;
        padding-right: 3px; }
    QTabBar::tab:left, QDockWidget QTabBar::tab:left {
      background-color: #D8D8D8;
      margin-top: 2px;
      padding-left: 2px;
      padding-right: 2px;
      padding-top: 4px;
      padding-bottom: 4px;
      border-top-left-radius: 4px;
      border-bottom-left-radius: 4px;
      min-height: 5px; }
      QTabBar::tab:left:selected, QDockWidget QTabBar::tab:left:selected {
        background-color: #CCCCCC;
        border-right: 3px solid #99E4FF; }
      QTabBar::tab:left:!selected:hover, QDockWidget QTabBar::tab:left:!selected:hover {
        border: 1px solid #66D6FF;
        border-right: 3px solid #66D6FF;
        /* Fixes different behavior #271 */
        margin-right: 0px;
        padding-right: -1px; }
    QTabBar::tab:right, QDockWidget QTabBar::tab:right {
      background-color: #D8D8D8;
      margin-top: 2px;
      padding-left: 2px;
      padding-right: 2px;
      padding-top: 4px;
      padding-bottom: 4px;
      border-top-right-radius: 4px;
      border-bottom-right-radius: 4px;
      min-height: 5px; }
      QTabBar::tab:right:selected, QDockWidget QTabBar::tab:right:selected {
        background-color: #CCCCCC;
        border-left: 3px solid #99E4FF; }
      QTabBar::tab:right:!selected:hover, QDockWidget QTabBar::tab:right:!selected:hover {
        border: 1px solid #66D6FF;
        border-left: 3px solid #66D6FF;
        /* Fixes different behavior #271 */
        margin-left: 0px;
        padding-left: 0px; }
  QTabBar QToolButton, QDockWidget QTabBar QToolButton {
    /* Fixes #136 */
    background-color: #D8D8D8;
    height: 12px;
    width: 12px; }
    QTabBar QToolButton:pressed, QDockWidget QTabBar QToolButton:pressed {
      background-color: #D8D8D8; }
      QTabBar QToolButton:pressed:hover, QDockWidget QTabBar QToolButton:pressed:hover {
        border: 1px solid #33C9FF; }
    QTabBar QToolButton::left-arrow:enabled, QDockWidget QTabBar QToolButton::left-arrow:enabled {
      image: url("theme-icons:black/feather/arrow_left.png"); }
    QTabBar QToolButton::left-arrow:disabled, QDockWidget QTabBar QToolButton::left-arrow:disabled {
      image: url("theme-icons:black/feather/arrow_left.png"); }
    QTabBar QToolButton::right-arrow:enabled, QDockWidget QTabBar QToolButton::right-arrow:enabled {
      image: url("theme-icons:black/feather/arrow_right.png"); }
    QTabBar QToolButton::right-arrow:disabled, QDockWidget QTabBar QToolButton::right-arrow:disabled {
      image: url("theme-icons:black/feather/arrow_right.png"); }

/* QDockWiget -------------------------------------------------------------

--------------------------------------------------------------------------- */
QDockWidget {
  outline: 1px solid #D8D8D8;
  background-color: white;
  border: 1px solid #D8D8D8;
  border-radius: 4px;
  titlebar-close-icon: url("theme-icons:black/feather/transparent.png");
  titlebar-normal-icon: url("theme-icons:black/feather/transparent.png"); }
  QDockWidget::title {
    /* Better size for title bar */
    padding: 3px;
    spacing: 4px;
    border: none;
    background-color: #D8D8D8; }
  QDockWidget::close-button {
    icon-size: 12px;
    border: none;
    background: transparent;
    background-image: transparent;
    border: 0;
    margin: 0;
    padding: 0;
    image: url("theme-icons:black/feather/window_close.png"); }
    QDockWidget::close-button:hover {
      image: url("theme-icons:black/feather/window_close.png"); }
    QDockWidget::close-button:pressed {
      image: url("theme-icons:black/feather/window_close_pressed.png"); }
  QDockWidget::float-button {
    icon-size: 12px;
    border: none;
    background: transparent;
    background-image: transparent;
    border: 0;
    margin: 0;
    padding: 0;
    image: url("theme-icons:black/feather/window_undock.png"); }
    QDockWidget::float-button:hover {
      image: url("theme-icons:black/feather/window_undock.png"); }
    QDockWidget::float-button:pressed {
      image: url("theme-icons:black/feather/window_undock_pressed.png"); }

/* QTreeView QListView QTableView -----------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qtreeview
https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qlistview
https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qtableview

--------------------------------------------------------------------------- */
QTreeView:branch:selected, QTreeView:branch:hover {
  background: url("theme-icons:black/feather/transparent.png"); }

QTreeView:branch:has-siblings:!adjoins-item {
  border-image: url("theme-icons:black/feather/branch_line.png") 0; }

QTreeView:branch:has-siblings:adjoins-item {
  border-image: url("theme-icons:black/feather/branch_more.png") 0; }

QTreeView:branch:!has-children:!has-siblings:adjoins-item {
  border-image: url("theme-icons:black/feather/branch_end.png") 0; }

QTreeView:branch:has-children:!has-siblings:closed, QTreeView:branch:closed:has-children:has-siblings {
  border-image: none;
  image: url("theme-icons:black/feather/branch_closed.png"); }

QTreeView:branch:open:has-children:!has-siblings, QTreeView:branch:open:has-children:has-siblings {
  border-image: none;
  image: url("theme-icons:black/feather/branch_open.png"); }

QTreeView:branch:has-children:!has-siblings:closed:hover, QTreeView:branch:closed:has-children:has-siblings:hover {
  image: url("theme-icons:black/feather/branch_closed.png"); }

QTreeView:branch:open:has-children:!has-siblings:hover, QTreeView:branch:open:has-children:has-siblings:hover {
  image: url("theme-icons:black/feather/branch_open.png"); }

QTreeView::indicator:checked,
QListView::indicator:checked,
QTableView::indicator:checked,
QColumnView::indicator:checked {
  image: url("theme-icons:black/feather/checkbox_checked.png"); }
  QTreeView::indicator:checked:hover, QTreeView::indicator:checked:focus, QTreeView::indicator:checked:pressed,
  QListView::indicator:checked:hover,
  QListView::indicator:checked:focus,
  QListView::indicator:checked:pressed,
  QTableView::indicator:checked:hover,
  QTableView::indicator:checked:focus,
  QTableView::indicator:checked:pressed,
  QColumnView::indicator:checked:hover,
  QColumnView::indicator:checked:focus,
  QColumnView::indicator:checked:pressed {
    image: url("theme-icons:black/feather/checkbox_checked.png"); }

QTreeView::indicator:unchecked,
QListView::indicator:unchecked,
QTableView::indicator:unchecked,
QColumnView::indicator:unchecked {
  image: url("theme-icons:black/feather/checkbox_unchecked.png"); }
  QTreeView::indicator:unchecked:hover, QTreeView::indicator:unchecked:focus, QTreeView::indicator:unchecked:pressed,
  QListView::indicator:unchecked:hover,
  QListView::indicator:unchecked:focus,
  QListView::indicator:unchecked:pressed,
  QTableView::indicator:unchecked:hover,
  QTableView::indicator:unchecked:focus,
  QTableView::indicator:unchecked:pressed,
  QColumnView::indicator:unchecked:hover,
  QColumnView::indicator:unchecked:focus,
  QColumnView::indicator:unchecked:pressed {
    image: url("theme-icons:black/feather/checkbox_unchecked.png"); }

QTreeView::indicator:indeterminate,
QListView::indicator:indeterminate,
QTableView::indicator:indeterminate,
QColumnView::indicator:indeterminate {
  image: url("theme-icons:black/feather/checkbox_indeterminate.png"); }
  QTreeView::indicator:indeterminate:hover, QTreeView::indicator:indeterminate:focus, QTreeView::indicator:indeterminate:pressed,
  QListView::indicator:indeterminate:hover,
  QListView::indicator:indeterminate:focus,
  QListView::indicator:indeterminate:pressed,
  QTableView::indicator:indeterminate:hover,
  QTableView::indicator:indeterminate:focus,
  QTableView::indicator:indeterminate:pressed,
  QColumnView::indicator:indeterminate:hover,
  QColumnView::indicator:indeterminate:focus,
  QColumnView::indicator:indeterminate:pressed {
    image: url("theme-icons:black/feather/checkbox_indeterminate.png"); }

QTreeView,
QListView,
QTableView,
QColumnView {
  background-color: white;
  border: 1px solid #D8D8D8;
  color: black;
  gridline-color: #D8D8D8;
  border-radius: 4px; }
  QTreeView:disabled,
  QListView:disabled,
  QTableView:disabled,
  QColumnView:disabled {
    background-color: white;
    color: #999999; }
  QTreeView:selected,
  QListView:selected,
  QTableView:selected,
  QColumnView:selected {
    background-color: #33C9FF;
    color: #D8D8D8; }
  QTreeView:focus,
  QListView:focus,
  QTableView:focus,
  QColumnView:focus {
    border: 1px solid #66D6FF; }
  QTreeView::item:pressed,
  QListView::item:pressed,
  QTableView::item:pressed,
  QColumnView::item:pressed {
    background-color: #33C9FF; }
  QTreeView::item:selected:active,
  QListView::item:selected:active,
  QTableView::item:selected:active,
  QColumnView::item:selected:active {
    background-color: #33C9FF; }
  QTreeView::item:selected:!active,
  QListView::item:selected:!active,
  QTableView::item:selected:!active,
  QColumnView::item:selected:!active {
    color: black;
    background-color: #E5E5E5; }
  QTreeView::item:!selected:hover,
  QListView::item:!selected:hover,
  QTableView::item:!selected:hover,
  QColumnView::item:!selected:hover {
    outline: 0;
    color: black;
    background-color: #E5E5E5; }

QTableCornerButton::section {
  background-color: white;
  border: 1px transparent #D8D8D8;
  border-radius: 0px; }

/* QHeaderView ------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qheaderview

--------------------------------------------------------------------------- */
QHeaderView {
  background-color: #D8D8D8;
  border: 0px transparent #D8D8D8;
  padding: 0;
  margin: 0;
  border-radius: 0; }
  QHeaderView:disabled {
    background-color: #D8D8D8;
    border: 1px transparent #D8D8D8; }
  QHeaderView::section {
    background-color: #D8D8D8;
    color: black;
    border-radius: 0;
    text-align: left;
    font-size: 13px; }
    QHeaderView::section::horizontal {
      padding-top: 0;
      padding-bottom: 0;
      padding-left: 4px;
      padding-right: 4px;
      border-left: 1px solid white; }
      QHeaderView::section::horizontal::first, QHeaderView::section::horizontal::only-one {
        border-left: 1px solid #D8D8D8; }
      QHeaderView::section::horizontal:disabled {
        color: #999999; }
    QHeaderView::section::vertical {
      padding-top: 0;
      padding-bottom: 0;
      padding-left: 4px;
      padding-right: 4px;
      border-top: 1px solid white; }
      QHeaderView::section::vertical::first, QHeaderView::section::vertical::only-one {
        border-top: 1px solid #D8D8D8; }
      QHeaderView::section::vertical:disabled {
        color: #999999; }
  QHeaderView::down-arrow {
    /* Those settings (border/width/height/background-color) solve bug */
    /* transparent arrow background and size */
    background-color: #D8D8D8;
    border: none;
    height: 12px;
    width: 12px;
    padding-left: 2px;
    padding-right: 2px;
    image: url("theme-icons:black/feather/arrow_down.png"); }
  QHeaderView::up-arrow {
    background-color: #D8D8D8;
    border: none;
    height: 12px;
    width: 12px;
    padding-left: 2px;
    padding-right: 2px;
    image: url("theme-icons:black/feather/arrow_up.png"); }

/* QToolBox --------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qtoolbox

--------------------------------------------------------------------------- */
QToolBox {
  padding: 0px;
  border: 0px;
  border: 1px solid #D8D8D8; }
  QToolBox:selected {
    padding: 0px;
    border: 2px solid #33C9FF; }
  QToolBox::tab {
    background-color: white;
    border: 1px solid #D8D8D8;
    color: black;
    border-top-left-radius: 4px;
    border-top-right-radius: 4px; }
    QToolBox::tab:disabled {
      color: #999999; }
    QToolBox::tab:selected {
      background-color: #BFBFBF;
      border-bottom: 2px solid #33C9FF; }
      QToolBox::tab:selected:disabled {
        background-color: #D8D8D8;
        border-bottom: 2px solid #00bcff; }
    QToolBox::tab:!selected {
      background-color: #D8D8D8;
      border-bottom: 2px solid #D8D8D8; }
      QToolBox::tab:!selected:disabled {
        background-color: white; }
    QToolBox::tab:hover {
      border-color: #66D6FF;
      border-bottom: 2px solid #66D6FF; }
  QToolBox QScrollArea QWidget QWidget {
    padding: 0px;
    border: 0px;
    background-color: white; }

/* QFrame -----------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qframe
https://doc.qt.io/qt-5/qframe.html#-prop
https://doc.qt.io/qt-5/qframe.html#details
https://stackoverflow.com/questions/14581498/qt-stylesheet-for-hline-vline-color

--------------------------------------------------------------------------- */
/* (dot) .QFrame  fix #141, #126, #123 */
.QFrame {
  border-radius: 4px;
  /* No frame */
  /* HLine */
  /* HLine */ }
  .QFrame[frameShape="0"] {
    border-radius: 4px;
    border: 1px transparent #D8D8D8; }
  .QFrame[frameShape="4"] {
    max-height: 2px;
    border: none;
    background-color: #D8D8D8; }
  .QFrame[frameShape="5"] {
    max-width: 2px;
    border: none;
    background-color: #D8D8D8; }

/* QSplitter --------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qsplitter

--------------------------------------------------------------------------- */
QSplitter {
  background-color: #D8D8D8;
  spacing: 0px;
  padding: 0px;
  margin: 0px; }
  QSplitter::handle {
    background-color: #D8D8D8;
    border: 0px solid white;
    spacing: 0px;
    padding: 1px;
    margin: 0px; }
    QSplitter::handle:hover {
      background-color: #999999; }
    QSplitter::handle:horizontal {
      width: 5px;
      image: url("theme-icons:black/feather/line_vertical.png"); }
    QSplitter::handle:vertical {
      height: 5px;
      image: url("theme-icons:black/feather/line_horizontal.png"); }

/* QDateEdit, QDateTimeEdit -----------------------------------------------

--------------------------------------------------------------------------- */
QDateEdit, QDateTimeEdit {
  selection-background-color: #33C9FF;
  border-style: solid;
  border: 1px solid #D8D8D8;
  border-radius: 4px;
  /* This fixes 103, 111 */
  padding-top: 2px;
  /* This fixes 103, 111 */
  padding-bottom: 2px;
  padding-left: 4px;
  padding-right: 4px;
  min-width: 10px; }
  QDateEdit:on, QDateTimeEdit:on {
    selection-background-color: #33C9FF; }
  QDateEdit::drop-down, QDateTimeEdit::drop-down {
    subcontrol-origin: padding;
    subcontrol-position: top right;
    width: 12px;
    border-left: 1px solid #D8D8D8; }
  QDateEdit::down-arrow, QDateTimeEdit::down-arrow {
    image: url("theme-icons:black/feather/arrow_down.png");
    height: 8px;
    width: 8px; }
    QDateEdit::down-arrow:on, QDateEdit::down-arrow:hover, QDateEdit::down-arrow:focus, QDateTimeEdit::down-arrow:on, QDateTimeEdit::down-arrow:hover, QDateTimeEdit::down-arrow:focus {
      image: url("theme-icons:black/feather/arrow_down.png"); }
  QDateEdit QAbstractItemView, QDateTimeEdit QAbstractItemView {
    background-color: white;
    border-radius: 4px;
    border: 1px solid #D8D8D8;
    selection-background-color: #33C9FF; }

/* QAbstractView ----------------------------------------------------------

--------------------------------------------------------------------------- */
QAbstractView:hover {
  border: 1px solid #33C9FF;
  color: black; }

QAbstractView:selected {
  background: #33C9FF;
  color: #D8D8D8; }

/* PlotWidget -------------------------------------------------------------

--------------------------------------------------------------------------- */
PlotWidget {
  /* Fix cut labels in plots #134 */
  padding: 0px; }
